@@ -1,11 +1,11 @@
-import xml.etree.ElementTree as ET
+from typing import Optional
 
 from indi.message import checks, const
-from indi.message.base import IndiMessage, IndiMessagePart
+from indi.message.base import IndiMessagePart
 
 
 class DefIndiMessagePart(IndiMessagePart):
-    def __init__(self, name, value=None, label=None, **junk):
+    def __init__(self, name: str, value=None, label: Optional[str] = None, **junk):
         super().__init__(name=name, value=value)
         self.label = label
 
@@ -20,7 +20,17 @@ class DefLight(DefIndiMessagePart):
 
 
 class DefNumber(DefIndiMessagePart):
-    def __init__(self, name, format, min, max, step, value=None, label=None, **junk):
+    def __init__(
+        self,
+        name: str,
+        format,
+        min: float,
+        max: float,
+        step: float,
+        value=None,
+        label: Optional[str] = None,
+        **junk
+    ):
         super().__init__(name=name, value=value, label=label)
         self.format = format
         self.min = min
